Index: base/i18n/rtl.h |
diff --git a/base/i18n/rtl.h b/base/i18n/rtl.h |
index c80d2f85777e6d31745057381618011fa549d45c..0d929a32d66677e2bec568c0e214090cdb36dc82 100644 |
--- a/base/i18n/rtl.h |
+++ b/base/i18n/rtl.h |
@@ -64,7 +64,7 @@ BASE_I18N_EXPORT bool ICUIsRTL(); |
BASE_I18N_EXPORT TextDirection GetTextDirectionForLocale( |
const char* locale_name); |
// Given the string in |text|, returns the directionality of the first |
// character with strong directionality in the string. If no character in the |
// text has strong directionality, LEFT_TO_RIGHT is returned. The Bidi |
// character types L, LRE, LRO, R, AL, RLE, and RLO are considered as strong |
@@ -73,6 +73,9 @@ BASE_I18N_EXPORT TextDirection GetTextDirectionForLocale( |
BASE_I18N_EXPORT TextDirection GetFirstStrongCharacterDirection( |
const string16& text); |
msw
2013/12/12 19:28:29
nit: remove blank line
Anuj
2013/12/13 01:23:50
Done.
|
+BASE_I18N_EXPORT TextDirection GetLastStrongCharacterDirection( |
+ const string16& text); |
+ |
// Given the string in |text|, returns LEFT_TO_RIGHT or RIGHT_TO_LEFT if all the |
// strong directionality characters in the string are of the same |
// directionality. It returns UNKNOWN_DIRECTION if the string contains a mix of |
@@ -64,7 +64,7 @@ BASE_I18N_EXPORT bool ICUIsRTL(); |
BASE_I18N_EXPORT TextDirection GetTextDirectionForLocale( |
const char* locale_name); |
-// Given the string in |text|, returns the directionality of the first |
+// Given the string in |text|, returns the directionality of the first or last |
// character with strong directionality in the string. If no character in the |
// text has strong directionality, LEFT_TO_RIGHT is returned. The Bidi |